==> kubernetes-model-1.0.60-sources.jar: io/fabric8/kubernetes/api/model/NamespaceStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class NamespaceStatusBuilder extends NamespaceStatusFluentImpl<NamespaceStatusBuilder> implements VisitableBuilder<NamespaceStatus,NamespaceStatusBuilder>{

    NamespaceStatusFluent<?> fluent;
    Boolean validationEnabled;

    public NamespaceStatusBuilder(){
            this(true);
    }
    public NamespaceStatusBuilder(Boolean validationEnabled){
            this(new NamespaceStatus(), validationEnabled);
    }
    public NamespaceStatusBuilder(NamespaceStatusFluent<?> fluent){
            this(fluent, true);
    }
    public NamespaceStatusBuilder(NamespaceStatusFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new NamespaceStatus(), validationEnabled);
    }
    public NamespaceStatusBuilder(NamespaceStatusFluent<?> fluent,NamespaceStatus instance){
            this(fluent, instance, true);
    }
    public NamespaceStatusBuilder(NamespaceStatusFluent<?> fluent,NamespaceStatus instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withPhase(instance.getPhase()); 
            this.validationEnabled = validationEnabled; 
    }
    public NamespaceStatusBuilder(NamespaceStatus instance){
            this(instance,true);
    }
    public NamespaceStatusBuilder(NamespaceStatus instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withPhase(instance.getPhase()); 
            this.validationEnabled = validationEnabled; 
    }

    public NamespaceStatus build(){
            NamespaceStatus buildable = new NamespaceStatus(fluent.getPhase());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            NamespaceStatusBuilder that = (NamespaceStatusBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-4.1.0-sources.jar: io/fabric8/kubernetes/api/model/NamespaceStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
import javax.validation.Validator;

public class NamespaceStatusBuilder extends NamespaceStatusFluentImpl<NamespaceStatusBuilder> implements VisitableBuilder<NamespaceStatus,NamespaceStatusBuilder>{

    NamespaceStatusFluent<?> fluent;
    Boolean validationEnabled;
    Validator validator;

    public NamespaceStatusBuilder(){
            this(true);
    }
    public NamespaceStatusBuilder(Boolean validationEnabled){
            this(new NamespaceStatus(), validationEnabled);
    }
    public NamespaceStatusBuilder(NamespaceStatusFluent<?> fluent){
            this(fluent, true);
    }
    public NamespaceStatusBuilder(NamespaceStatusFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new NamespaceStatus(), validationEnabled);
    }
    public NamespaceStatusBuilder(NamespaceStatusFluent<?> fluent,NamespaceStatus instance){
            this(fluent, instance, true);
    }
    public NamespaceStatusBuilder(NamespaceStatusFluent<?> fluent,NamespaceStatus instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withPhase(instance.getPhase()); 
            this.validationEnabled = validationEnabled; 
    }
    public NamespaceStatusBuilder(NamespaceStatus instance){
            this(instance,true);
    }
    public NamespaceStatusBuilder(NamespaceStatus instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withPhase(instance.getPhase()); 
            this.validationEnabled = validationEnabled; 
    }
    public NamespaceStatusBuilder(Validator validator){
            this(new NamespaceStatus(), true);
    }
    public NamespaceStatusBuilder(NamespaceStatusFluent<?> fluent,NamespaceStatus instance,Validator validator){
            this.fluent = fluent; 
            fluent.withPhase(instance.getPhase()); 
            this.validator = validator;
            this.validationEnabled = validator != null; 
    }
    public NamespaceStatusBuilder(NamespaceStatus instance,Validator validator){
            this.fluent = this; 
            this.withPhase(instance.getPhase()); 
            this.validator = validator; 
            this.validationEnabled = validator != null; 
    }

    public NamespaceStatus build(){
            NamespaceStatus buildable = new NamespaceStatus(fluent.getPhase());
            if (validationEnabled) {io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable, validator);}
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            NamespaceStatusBuilder that = (NamespaceStatusBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
